@@ -1,6 +1,6 @@
 #include <init.h>
 #include <io.h>
-#include <sizes.h>
+#include <linux/sizes.h>
 #include <asm/barebox-arm-head.h>
 #include <asm/barebox-arm.h>
 #include <mach/control.h>
