@@ -26,7 +26,7 @@
 #include <io.h>
 #include <mach/hardware.h>
 #include <nand.h>
-#include <sizes.h>
+#include <linux/sizes.h>
 #include <linux/mtd/nand.h>
 #include <linux/clk.h>
 #include <mach/board.h>
